.. _apiref:

===============
 API Reference
===============

:Release: |version|
:Date: |today|

.. toctree::
    :maxdepth: 1

    django_celery_monitor.camera
    django_celery_monitor.humanize
    django_celery_monitor.managers
    django_celery_monitor.models
    django_celery_monitor.utils
